==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fa/admin/hardware/message.php <==
<?php

return array(

    'undeployable' 		=> '<strong> اخطار: </ strong> این دارایی به برانگیز گزارش شده است که در حال حاضر undeployable. اگر این وضعیت تغییر کرده است، لطفا به روز رسانی وضعیت دارایی.',
    'does_not_exist' 	=> 'دارایی وجود ندارد.',
    'does_not_exist_or_not_requestable' => 'دوباره تلاش کنید . این دارایی وجود ندارد.',
    'assoc_users'	 	=> 'این دارایی در حال حاضر به یک کاربر چک کردن و پاک نمی شود. لطفا دارایی در اولین بار چک کنید، و سپس سعی کنید دوباره حذف کنید.',

    'create' => array(
        'error'   		=> 'دارایی ساخته نشده است، لطفا دوباره تلاش کنید.',
        'success' 		=> 'دارایی موفقیت ایجاد شده است. :)'
    ),

    'update' => array(
        'error'   			=> 'دارایی به روز نیست، لطفا دوباره امتحان کنید',
        'success' 			=> 'دارایی ها با موفقیت به روز رسانی.',
        'nothing_updated'	=>  'هیچ زمینه، انتخاب شدند تا هیچ چیز به روز شد.',
    ),

    'restore' => array(
        'error'   		=> 'دارایی بازیابی نشد، لطفا دوباره تلاش کنید',
        'success' 		=> 'دارایی با موفقیت بازیابی شد.'
    ),

    'audit' => array(
        'error'   		=> 'ممیزی دارایی ناموفق بود. لطفا دوباره تلاش کنید.',
        'success' 		=> 'حسابرسی املاک با موفقیت وارد شد'
    ),


    'deletefile' => array(
        'error'   => 'فایل حذف نمی شود. لطفا دوباره تلاش کنید.',
        'success' => 'فایل با موفقیت حذف شده است.',
    ),

    'upload' => array(
        'error'   => 'فایل) آپلود نیست. لطفا دوباره تلاش کنید.',
        'success' => 'فایل (موفقیت آپلود شد.',
        'nofiles' => 'شما هر فایل برای آپلود انتخاب کنید، و یا فایل شما در حال تلاش برای آپلود بیش از حد بزرگ است',
        'invalidfiles' => 'یک یا بیشتر از فایل های خود را بیش از حد بزرگ است یا یک نوع فایل است که مجاز است. انواع فایل های مجاز عبارتند از PNG، GIF، JPG، DOC، DOCX، PDF، TXT و.',
    ),

    'import' => array(
        'error'                 => 'بعضی از موارد به درستی وارد نشدند.',
        'errorDetail'           => 'موارد زیر به علت خطا وارد نشده است.',
        'success'               => "فایل شما وارد شده است",
        'file_delete_success'   => "فایل شما با موفقیت حذف شده است",
        'file_delete_error'      => "فایل قابل حذف نشد",
    ),


    'delete' => array(
        'confirm'   	=> 'آیا شما مطمئن هستید که می خواهید این تنظیمات دارایی را حذف کنید؟',
        'error'   		=> 'اشکال در حذف دارایی.لطفا دوباره تلاش کنید.',
        'nothing_updated'   => 'هیچ دارایی انتخاب نشده بود، بنابراین هیچ چیز حذف نشد.',
        'success' 		=> 'دارایی با موفقیت حذف شد.'
    ),

    'checkout' => array(
        'error'   		=> 'دارایی در بررسی نیست، لطفا دوباره امتحان کنید',
        'success' 		=> 'دارایی را بررسی کنید موفقیت.',
        'user_does_not_exist' => 'کاربر نامعتبر است لطفا دوباره امتحان کنید.',
        'not_available' => 'این دارایی برای پرداخت در دسترس نیست!',
        'no_assets_selected' => 'شما حداقل باید یک دارایی از لیست انتخاب کنید'
    ),

    'checkin' => array(
        'error'   		=> 'دارایی در بررسی نیست، لطفا دوباره امتحان کنید',
        'success' 		=> 'دارایی ها با موفقیت در بررسی.',
        'user_does_not_exist' => 'آن کاربر نامعتبر است. لطفا دوباره سعی کنید.',
        'already_checked_in'  => 'دارایی ها که در حال حاضر انتخاب شده است.',

    ),

    'requests' => array(
        'error'   		=> 'دارایی شد درخواست نمی کند، لطفا دوباره امتحان کنید',
        'success' 		=> 'دارایی موفقیت درخواست شده است.',
        'canceled'      => 'درخواست پرداخت با موفقیت لغو شد'
    )

);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fa/admin/hardware/message.php <==
<?php

return [

    'undeployable' 		=> '<strong> اخطار: </ strong> این دارایی به برانگیز گزارش شده است که در حال حاضر undeployable. اگر این وضعیت تغییر کرده است، لطفا به روز رسانی وضعیت دارایی.',
    'does_not_exist' 	=> 'دارایی وجود ندارد.',
    'does_not_exist_or_not_requestable' => 'That asset does not exist or is not requestable.',
    'assoc_users'	 	=> 'این دارایی در حال حاضر به یک کاربر چک کردن و پاک نمی شود. لطفا دارایی در اولین بار چک کنید، و سپس سعی کنید دوباره حذف کنید.',

    'create' => [
        'error'   		=> 'دارایی ساخته نشده است، لطفا دوباره تلاش کنید.',
        'success' 		=> 'دارایی موفقیت ایجاد شده است. :)',
    ],

    'update' => [
        'error'   			=> 'دارایی به روز نیست، لطفا دوباره امتحان کنید',
        'success' 			=> 'دارایی ها با موفقیت به روز رسانی.',
        'nothing_updated'	=>  'هیچ زمینه، انتخاب شدند تا هیچ چیز به روز شد.',
    ],

    'restore' => [
        'error'   		=> 'دارایی بازیابی نشد، لطفا دوباره تلاش کنید',
        'success' 		=> 'دارایی با موفقیت بازیابی شد.',
    ],

    'audit' => [
        'error'   		=> 'ممیزی دارایی ناموفق بود. لطفا دوباره تلاش کنید.',
        'success' 		=> 'حسابرسی املاک با موفقیت وارد شد',
    ],


    'deletefile' => [
        'error'   => 'فایل حذف نمی شود. لطفا دوباره تلاش کنید.',
        'success' => 'فایل با موفقیت حذف شده است.',
    ],

    'upload' => [
        'error'   => 'فایل) آپلود نیست. لطفا دوباره تلاش کنید.',
        'success' => 'فایل (موفقیت آپلود شد.',
        'nofiles' => 'شما هر فایل برای آپلود انتخاب کنید، و یا فایل شما در حال تلاش برای آپلود بیش از حد بزرگ است',
        'invalidfiles' => 'یک یا بیشتر از فایل های خود را بیش از حد بزرگ است یا یک نوع فایل است که مجاز است. انواع فایل های مجاز عبارتند از PNG، GIF، JPG، DOC، DOCX، PDF، TXT و.',
    ],

    'import' => [
        'error'                 => 'بعضی از موارد به درستی وارد نشدند.',
        'errorDetail'           => 'موارد زیر به علت خطا وارد نشده است.',
        'success'               => 'فایل شما وارد شده است',
        'file_delete_success'   => 'فایل شما با موفقیت حذف شده است',
        'file_delete_error'      => 'فایل قابل حذف نشد',
    ],


    'delete' => [
        'confirm'   	=> 'آیا شما مطمئن هستید که می خواهید این تنظیمات دارایی را حذف کنید؟',
        'error'   		=> 'اشکال در حذف دارایی.لطفا دوباره تلاش کنید.',
        'nothing_updated'   => 'هیچ دارایی انتخاب نشده بود، بنابراین هیچ چیز حذف نشد.',
        'success' 		=> 'دارایی با موفقیت حذف شد.',
    ],

    'checkout' => [
        'error'   		=> 'دارایی در بررسی نیست، لطفا دوباره امتحان کنید',
        'success' 		=> 'دارایی را بررسی کنید موفقیت.',
        'user_does_not_exist' => 'کاربر نامعتبر است لطفا دوباره امتحان کنید.',
        'not_available' => 'این دارایی برای پرداخت در دسترس نیست!',
        'no_assets_selected' => 'شما حداقل باید یک دارایی از لیست انتخاب کنید',
    ],

    'checkin' => [
        'error'   		=> 'دارایی در بررسی نیست، لطفا دوباره امتحان کنید',
        'success' 		=> 'دارایی ها با موفقیت در بررسی.',
        'user_does_not_exist' => 'آن کاربر نامعتبر است. لطفا دوباره سعی کنید.',
        'already_checked_in'  => 'دارایی ها که در حال حاضر انتخاب شده است.',

    ],

    'requests' => [
        'error'   		=> 'دارایی شد درخواست نمی کند، لطفا دوباره امتحان کنید',
        'success' 		=> 'دارایی موفقیت درخواست شده است.',
        'canceled'      => 'درخواست پرداخت با موفقیت لغو شد',
    ],

];
